@@ -3,19 +3,20 @@
 # Crypt::RSA::Blind - Blind RSA signatures
 # Copyright (c) Ashish Gulhati <crypt-rsab at hash.neo.email>
 #
-# $Id: lib/Crypt/RSA/Blind.pm v1.023 Tue Jun  3 09:04:18 EST 2025 $
+# $Id: lib/Crypt/RSA/Blind.pm v1.024 Tue Jun  3 22:17:05 EST 2025 $
 
 use warnings;
 use strict;
 
-use v5.14;
+use v5.20;
 use Feature::Compat::Class;
 use feature qw(signatures);
+no warnings qw(experimental::signatures);
 
 class Crypt::RSA::Blind {
 
   use vars qw( $VERSION );
-  our ( $VERSION ) = '$Revision: 1.023 $' =~ /\s+([\d\.]+)/;
+  our ( $VERSION ) = '$Revision: 1.024 $' =~ /\s+([\d\.]+)/;
 
   use Carp;
   use Carp::Assert;
@@ -331,8 +332,8 @@ Crypt::RSA::Blind - Blind RSA signatures
 
 =head1 VERSION
 
- $Revision: 1.023 $
- $Date: Tue Jun  3 09:04:18 EST 2025 $
+ $Revision: 1.024 $
+ $Date: Tue Jun  3 22:17:05 EST 2025 $
 
 =cut
 
@@ -701,17 +702,19 @@ above).
 
 Ashish Gulhati, C<< <crypt-rsab at hash.neo.email> >>
 
-=head1 BUGS AND FEATURE REQUESTS
+=head1 BUGS
 
 Please report any bugs or feature requests to C<bug-crypt-rsa-blind at rt.cpan.org>,
 or through the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Crypt-RSA-Blind>. 
 I will be notified, and then you'll automatically be notified of progress
 on your bug as I make changes.
 
-=head1 LICENSE AND COPYRIGHT
+=head1 COPYRIGHT
 
 Copyright (c) Ashish Gulhati.
 
+=head1 LICENSE
+
 This software package is Open Software; you can use, redistribute,
 and/or modify it under the terms of the Open Artistic License 4.0.
 
